.. Django AllCaptcha documentation master file, created by
   sphinx-quickstart on Mon Dec 27 13:36:15 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django AllCaptcha's documentation!
=============================================

This package allows you to easily integrate captcha services in your Django project.

Currently, it supports:

- HCaptcha
- Invisible HCaptcha
- Recaptcha V2 Checkbox
- Invisible Recaptcha V2
- Recaptcha V3

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   tutorial
   settings
   template-tags




Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
